Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: content/browser/frame_host/navigation_controller_impl.cc

Issue 2841833002: Renamed LoadCommittedDetails.is_in_page to is_same_document. (Closed)
Patch Set: I said "once and for all" Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/chrome_bubble_manager.cc ('k') | content/browser/web_contents/web_contents_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigation_controller_impl.cc
diff --git a/content/browser/frame_host/navigation_controller_impl.cc b/content/browser/frame_host/navigation_controller_impl.cc
index c070f2dfdea9caaca7401e3fa1629c459fd2f1aa..53a02aa6fc71738a32bbb9a268fba5f8e1e90bb1 100644
--- a/content/browser/frame_host/navigation_controller_impl.cc
+++ b/content/browser/frame_host/navigation_controller_impl.cc
@@ -832,8 +832,8 @@ bool NavigationControllerImpl::RendererDidNavigate(
// Do navigation-type specific actions. These will make and commit an entry.
details->type = ClassifyNavigation(rfh, params);
- // is_in_page must be computed before the entry gets committed.
- details->is_in_page = is_navigation_within_page;
+ // is_same_document must be computed before the entry gets committed.
+ details->is_same_document = is_navigation_within_page;
// Save reload type and timestamp for a reload navigation to detect
// consecutive reloads when the next reload is requested.
@@ -851,20 +851,20 @@ bool NavigationControllerImpl::RendererDidNavigate(
switch (details->type) {
case NAVIGATION_TYPE_NEW_PAGE:
- RendererDidNavigateToNewPage(rfh, params, details->is_in_page,
+ RendererDidNavigateToNewPage(rfh, params, details->is_same_document,
details->did_replace_entry,
navigation_handle);
break;
case NAVIGATION_TYPE_EXISTING_PAGE:
- details->did_replace_entry = details->is_in_page;
- RendererDidNavigateToExistingPage(rfh, params, details->is_in_page,
+ details->did_replace_entry = details->is_same_document;
+ RendererDidNavigateToExistingPage(rfh, params, details->is_same_document,
was_restored, navigation_handle);
break;
case NAVIGATION_TYPE_SAME_PAGE:
RendererDidNavigateToSamePage(rfh, params, navigation_handle);
break;
case NAVIGATION_TYPE_NEW_SUBFRAME:
- RendererDidNavigateNewSubframe(rfh, params, details->is_in_page,
+ RendererDidNavigateNewSubframe(rfh, params, details->is_same_document,
details->did_replace_entry);
break;
case NAVIGATION_TYPE_AUTO_SUBFRAME:
« no previous file with comments | « chrome/browser/ui/chrome_bubble_manager.cc ('k') | content/browser/web_contents/web_contents_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698